@@ -1,6 +1,11 @@
 '''
 # CDK NAT ASG Provider
 
+![npm version](https://img.shields.io/npm/v/cdk-nat-asg-provider)
+![PyPi version](https://img.shields.io/pypi/v/cdk-nat-asg-provider)
+![Release](https://github.com/fonzcastellanos/cdk-nat-asg-provider/workflows/release/badge.svg)
+![License](https://img.shields.io/github/license/fonzcastellanos/cdk-nat-asg-provider)
+
 Use this [AWS Cloud Development Kit (CDK)](https://docs.aws.amazon.com/cdk/v2/guide/home.html) library to configure and deploy [Network Address Translation (NAT) instances](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_NAT_Instance.html) that are each in their own [auto scaling group (ASG)](https://docs.aws.amazon.com/autoscaling/ec2/userguide/auto-scaling-groups.html) to improve fault tolerance and availability.
 
 Works with AWS CDK <strong>v2</strong>.
@@ -66,7 +71,7 @@ At a high-level, this is how `NatAsgProvider` achieves its purpose:
 
 ## Installation
 
-### Typescript (npm)
+### TypeScript (npm)
 
 ```shell
 npm install cdk-nat-asg-provider
@@ -100,7 +105,7 @@ To **deploy** the manual integration test, execute the `sh` script `scripts/manu
 ./scripts/manual-integ-test deploy <ACCOUNT> <AWS_REGION> <KEY_PAIR_NAME> [MAX_AZS]
 ```
 
-`MAX_AZs` is optional.
+`MAX_AZS` is optional.
 
 To **destroy** the manual integration test, execute the same script with same arguments using the `destroy` command:
 
@@ -130,14 +135,16 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
-import aws_cdk.aws_ec2
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
 
 
-@jsii.implements(aws_cdk.aws_ec2.IConnectable)
+@jsii.implements(_aws_cdk_aws_ec2_ceddda9d.IConnectable)
 class NatAsgProvider(
-    aws_cdk.aws_ec2.NatProvider,
+    _aws_cdk_aws_ec2_ceddda9d.NatProvider,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-nat-asg-provider.NatAsgProvider",
 ):
@@ -152,10 +159,10 @@ class NatAsgProvider(
     def __init__(
         self,
         *,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
         key_pair: typing.Optional[builtins.str] = None,
-        security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
-        traffic_direction: typing.Optional[aws_cdk.aws_ec2.NatTrafficDirection] = None,
+        security_group: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup] = None,
+        traffic_direction: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.NatTrafficDirection] = None,
     ) -> None:
         '''
         :param instance_type: (experimental) The EC2 instance type of the NAT instances. Default: t2.micro
@@ -178,9 +185,9 @@ class NatAsgProvider(
     def configure_nat(
         self,
         *,
-        nat_subnets: typing.Sequence[aws_cdk.aws_ec2.PublicSubnet],
-        private_subnets: typing.Sequence[aws_cdk.aws_ec2.PrivateSubnet],
-        vpc: aws_cdk.aws_ec2.Vpc,
+        nat_subnets: typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.PublicSubnet],
+        private_subnets: typing.Sequence[_aws_cdk_aws_ec2_ceddda9d.PrivateSubnet],
+        vpc: _aws_cdk_aws_ec2_ceddda9d.Vpc,
     ) -> None:
         '''(experimental) Called by the VPC to configure NAT.
 
@@ -192,14 +199,14 @@ class NatAsgProvider(
 
         :stability: experimental
         '''
-        opts = aws_cdk.aws_ec2.ConfigureNatOptions(
+        opts = _aws_cdk_aws_ec2_ceddda9d.ConfigureNatOptions(
             nat_subnets=nat_subnets, private_subnets=private_subnets, vpc=vpc
         )
 
         return typing.cast(None, jsii.invoke(self, "configureNat", [opts]))
 
     @jsii.member(jsii_name="configureSubnet")
-    def configure_subnet(self, subnet: aws_cdk.aws_ec2.PrivateSubnet) -> None:
+    def configure_subnet(self, subnet: _aws_cdk_aws_ec2_ceddda9d.PrivateSubnet) -> None:
         '''(experimental) Configures subnet with the gateway.
 
         Don't call this directly, the VPC will call it automatically.
@@ -208,36 +215,41 @@ class NatAsgProvider(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__184a627c1e0d161db9765df0020e6448bbbdc653d1716896f093911988882812)
+            check_type(argname="argument subnet", value=subnet, expected_type=type_hints["subnet"])
         return typing.cast(None, jsii.invoke(self, "configureSubnet", [subnet]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="configuredGateways")
-    def configured_gateways(self) -> typing.List[aws_cdk.aws_ec2.GatewayConfig]:
+    def configured_gateways(
+        self,
+    ) -> typing.List[_aws_cdk_aws_ec2_ceddda9d.GatewayConfig]:
         '''(experimental) Return list of gateways spawned by the provider.
 
         :stability: experimental
         '''
-        return typing.cast(typing.List[aws_cdk.aws_ec2.GatewayConfig], jsii.get(self, "configuredGateways"))
+        return typing.cast(typing.List[_aws_cdk_aws_ec2_ceddda9d.GatewayConfig], jsii.get(self, "configuredGateways"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="connections")
-    def connections(self) -> aws_cdk.aws_ec2.Connections:
+    def connections(self) -> _aws_cdk_aws_ec2_ceddda9d.Connections:
         '''(experimental) The network connections associated with the security group of the NAT instances.
 
         :see: https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.Connections.html
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ec2.Connections, jsii.get(self, "connections"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.Connections, jsii.get(self, "connections"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="securityGroup")
-    def security_group(self) -> aws_cdk.aws_ec2.ISecurityGroup:
+    def security_group(self) -> _aws_cdk_aws_ec2_ceddda9d.ISecurityGroup:
         '''(experimental) The security group associated with the NAT instances.
 
         :see: https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.ISecurityGroup.html
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_ec2.ISecurityGroup, jsii.get(self, "securityGroup"))
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup, jsii.get(self, "securityGroup"))
 
 
 @jsii.data_type(
@@ -254,10 +266,10 @@ class NatAsgProviderProps:
     def __init__(
         self,
         *,
-        instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
+        instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
         key_pair: typing.Optional[builtins.str] = None,
-        security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
-        traffic_direction: typing.Optional[aws_cdk.aws_ec2.NatTrafficDirection] = None,
+        security_group: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup] = None,
+        traffic_direction: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.NatTrafficDirection] = None,
     ) -> None:
         '''(experimental) Properties to configure ``NatAsgProvider``.
 
@@ -268,7 +280,13 @@ class NatAsgProviderProps:
 
         :stability: experimental
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__1af8ce722e82004ed6755c9f667c245b1a2dc875c9cc9a1fe59b9036173984d9)
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument key_pair", value=key_pair, expected_type=type_hints["key_pair"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument traffic_direction", value=traffic_direction, expected_type=type_hints["traffic_direction"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if instance_type is not None:
             self._values["instance_type"] = instance_type
         if key_pair is not None:
@@ -279,7 +297,7 @@ class NatAsgProviderProps:
             self._values["traffic_direction"] = traffic_direction
 
     @builtins.property
-    def instance_type(self) -> typing.Optional[aws_cdk.aws_ec2.InstanceType]:
+    def instance_type(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType]:
         '''(experimental) The EC2 instance type of the NAT instances.
 
         :default: t2.micro
@@ -288,7 +306,7 @@ class NatAsgProviderProps:
         :stability: experimental
         '''
         result = self._values.get("instance_type")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.InstanceType], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType], result)
 
     @builtins.property
     def key_pair(self) -> typing.Optional[builtins.str]:
@@ -301,7 +319,9 @@ class NatAsgProviderProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def security_group(self) -> typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]:
+    def security_group(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup]:
         '''(experimental) The security group associated with the NAT instances.
 
         :default: A security group will be created.
@@ -310,10 +330,12 @@ class NatAsgProviderProps:
         :stability: experimental
         '''
         result = self._values.get("security_group")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.ISecurityGroup], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup], result)
 
     @builtins.property
-    def traffic_direction(self) -> typing.Optional[aws_cdk.aws_ec2.NatTrafficDirection]:
+    def traffic_direction(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.NatTrafficDirection]:
         '''(experimental) The allowed traffic directions through the NAT instances.
 
         If you set this to a value other than
@@ -330,7 +352,7 @@ class NatAsgProviderProps:
         :stability: experimental
         '''
         result = self._values.get("traffic_direction")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.NatTrafficDirection], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.NatTrafficDirection], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -350,3 +372,19 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__184a627c1e0d161db9765df0020e6448bbbdc653d1716896f093911988882812(
+    subnet: _aws_cdk_aws_ec2_ceddda9d.PrivateSubnet,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1af8ce722e82004ed6755c9f667c245b1a2dc875c9cc9a1fe59b9036173984d9(
+    *,
+    instance_type: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.InstanceType] = None,
+    key_pair: typing.Optional[builtins.str] = None,
+    security_group: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.ISecurityGroup] = None,
+    traffic_direction: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.NatTrafficDirection] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
